import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * This class defines a bug that lives on a wall.
 * 
 * @author Ed Parrish 
 * @version 1.0 
 */
public class Bug  extends Mover
{
    private GreenfootImage image1;
    private GreenfootImage image2;
    private int flowersEaten;

    public Bug()
    {
        image1 = new GreenfootImage("bug-a.gif");
        image2 = new GreenfootImage("bug-b.gif");
        setImage(image1);
        flowersEaten = 0;
    }
    
    /**
     * Act - do whatever the Bug wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        turnAtEdge();
        checkKeyPress();
        move();
        lookForFlower();
    }    

    /**
     * Check if a control key has been pressed and react.
     */
    public void checkKeyPress() {
        if (Greenfoot.isKeyDown("right"))
        {
            turn(10);
        }
        if (Greenfoot.isKeyDown("left"))
        {
            turn(-10);
        }
        updateImage();
    }

    /**
     * Turns at the edge of the world.
     */
    public void turnAtEdge()
    {
        if (atWorldEdge())
        {
            turn(17);
        }
    }

    /**
     * Checks whether we have stumbled upon a flower.
     * If we have, then eat it. Otherwise, do nothing.
     */
    public void lookForFlower()
    {
        if (canSee(Flower.class)) {
            eat(Flower.class);
            Greenfoot.playSound("slurp.wav");
            
            flowersEaten = flowersEaten + 1;
            if (flowersEaten >= 8) {
                Greenfoot.playSound("success.wav");
                Greenfoot.stop();
            }
        }
    }
    
    /**
     * Checks whether we have stumbled upon a flower.
     * If we have, then eat it. Otherwise, do nothing.
     */
    public void updateImage() {
        if (getImage() == image1)
        {
            setImage(image2);
        }
        else
        {
            setImage(image1);
        }
    }
}
